import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';

import LinkButton from './LinkButton';

import AnchorTestWrapper from '../../test-utils/AnchorTestWrapper';


const TestLinkButton = LinkButton({
    block: purebem.of('test-button'),
    displayName: 'TestLinkButton'
});

test('should navigate', () => {
    const wrapper = TestUtils.renderIntoDocument(
        <AnchorTestWrapper>
            <TestLinkButton />
        </AnchorTestWrapper>
    );

    const button = TestUtils.findRenderedComponentWithType(wrapper, TestLinkButton);
    const node = ReactDOM.findDOMNode(button);

    TestUtils.Simulate.click(node);

    expect(wrapper.didNavigate).toBeTruthy();
});

test('should trigger click event when clicked', () => {
    const onClick = jest.fn();

    const button = TestUtils.renderIntoDocument(
        <TestLinkButton
            onClick={ onClick } />
    );

    const node = ReactDOM.findDOMNode(button);

    TestUtils.Simulate.click(node);

    expect(onClick).toHaveBeenCalled();
});

test('should not trigger click event nor navigate when clicked and disabled', () => {
    const onClick = jest.fn();

    const wrapper = TestUtils.renderIntoDocument(
        <AnchorTestWrapper>
            <TestLinkButton
                disabled={ true }
                onClick={ onClick } />
        </AnchorTestWrapper>
    );

    const button = TestUtils.findRenderedComponentWithType(wrapper, TestLinkButton);
    const node = ReactDOM.findDOMNode(button);

    TestUtils.Simulate.click(node);

    expect(onClick).not.toHaveBeenCalled();
    expect(wrapper.didNavigate).toBeFalsy();
});
