import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';

import RouteButton from './RouteButton';

import AnchorTestWrapper from '../../test-utils/AnchorTestWrapper';


const TestRouteButton = RouteButton({
    block: purebem.of('test-button'),
    displayName: 'TestRouteButton'
});

test('should trigger click event when clicked', () => {
    let value = false;

    const button = TestUtils.renderIntoDocument(
        <TestRouteButton
            onClick={ (evt) => {
                evt.preventDefault(); // prevent react-router from blowing up.
                value = true;
            } } />
    );

    const node = ReactDOM.findDOMNode(button);

    TestUtils.Simulate.click(node);

    expect(value).toBeTruthy();
});

test('should not trigger click event nor navigate when clicked and disabled', () => {
    const onClick = jest.fn();

    const wrapper = TestUtils.renderIntoDocument(
        <AnchorTestWrapper>
            <TestRouteButton
                disabled={ true }
                onClick={ onClick } />
        </AnchorTestWrapper>
    );

    const button = TestUtils.findRenderedComponentWithType(wrapper, TestRouteButton);
    const node = ReactDOM.findDOMNode(button);

    TestUtils.Simulate.click(node);

    expect(onClick).not.toHaveBeenCalled();
    expect(wrapper.didNavigate).toBeFalsy();
});
